ReliableBroadcast

Struct ReliableBroadcast 

pub struct ReliableBroadcast<P: Clone, L: VolatileLink<Data<P>> = PerfectLink<Data<P>>> { /* private fields */ }
Broadcast with agreement, over best-effort broadcast.

Implementations

Source

impl<P: Clone> ReliableBroadcast<P, PerfectLink<Data<P>>>

pub fn new( me: NodeId, peers: impl IntoIterator<Item = NodeId>, interval: Duration, ) -> Self

Reliable broadcast for process me among peers, over links retransmitting every interval.

Source

impl<P: Clone, L: VolatileLink<Data<P>>> ReliableBroadcast<P, L>

Reliable broadcast for process me among peers, over the link supplied.

pub fn delivered_count(&self) -> usize

How many distinct broadcasts this process has delivered upward.

pub fn has_delivered(&self, id: BroadcastId) -> bool

Whether this process has already delivered id.