Carried

Type Alias Carried 

pub type Carried<P> = Data<P>;
What a link beneath this layer must carry.

A caller supplying their own link needs this and should not have to read the source to find it: the payload is wrapped as Data — the payload with the originator and sequence number Algorithm 3.3 needs, so the link carries Carried<P> rather than P.

Aliased Type

pub struct Carried<P> {
    pub id: BroadcastId,
    pub payload: P,
}

Fields

id: BroadcastIdpayload: P