pub struct ReliableBroadcast<P: Clone, L: VolatileLink<Data<P>> = PerfectLink<Data<P>>> { /* private fields */ }Expand description
Broadcast with agreement, over best-effort broadcast.
Implementations
Sourceimpl<P: Clone> ReliableBroadcast<P, PerfectLink<Data<P>>>
impl<P: Clone> ReliableBroadcast<P, PerfectLink<Data<P>>>
Sourcepub fn new(
me: NodeId,
peers: impl IntoIterator<Item = NodeId>,
interval: Duration,
) -> Self
pub fn new( me: NodeId, peers: impl IntoIterator<Item = NodeId>, interval: Duration, ) -> Self
Reliable broadcast for process me among peers, over links retransmitting every
interval.
Sourceimpl<P: Clone, L: VolatileLink<Data<P>>> ReliableBroadcast<P, L>
impl<P: Clone, L: VolatileLink<Data<P>>> ReliableBroadcast<P, L>
Sourcepub fn with_link(
me: NodeId,
peers: impl IntoIterator<Item = NodeId>,
link: L,
) -> Self
pub fn with_link( me: NodeId, peers: impl IntoIterator<Item = NodeId>, link: L, ) -> Self
Reliable broadcast for process me among peers, over the link supplied.
Sourcepub fn delivered_count(&self) -> usize
pub fn delivered_count(&self) -> usize
How many distinct broadcasts this process has delivered upward.
Sourcepub fn has_delivered(&self, id: BroadcastId) -> bool
pub fn has_delivered(&self, id: BroadcastId) -> bool
Whether this process has already delivered id.